==> igniteui-react-charts-18.5.1.tgz: package/esm5/lib/AccumulationDistributionIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AccumulationDistributionIndicatorStrategy } from "./AccumulationDistributionIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var AccumulationDistributionIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AccumulationDistributionIndicator, _super);
    function AccumulationDistributionIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AccumulationDistributionIndicator.prototype.bg = function () {
        return new AccumulationDistributionIndicator();
    };
    AccumulationDistributionIndicator.prototype.get_yz = function () {
        return new AccumulationDistributionIndicatorStrategy();
    };
    Object.defineProperty(AccumulationDistributionIndicator.prototype, "yz", {
        get: function () {
            return this.get_yz();
        },
        enumerable: false,
        configurable: true
    });
    AccumulationDistributionIndicator.prototype.get_zc = function () {
        return AccumulationDistributionIndicator.$;
    };
    Object.defineProperty(AccumulationDistributionIndicator.prototype, "zc", {
        get: function () {
            return this.get_zc();
        },
        enumerable: false,
        configurable: true
    });
    AccumulationDistributionIndicator.$t = markType(AccumulationDistributionIndicator, 'AccumulationDistributionIndicator', StrategyBasedIndicator.$);
    return AccumulationDistributionIndicator;
}(StrategyBasedIndicator));
export { AccumulationDistributionIndicator };

==> igniteui-react-charts-18.6.0.tgz: package/esm5/lib/AccumulationDistributionIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AccumulationDistributionIndicatorStrategy } from "./AccumulationDistributionIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var AccumulationDistributionIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AccumulationDistributionIndicator, _super);
    function AccumulationDistributionIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AccumulationDistributionIndicator.prototype.bc = function () {
        return new AccumulationDistributionIndicator();
    };
    AccumulationDistributionIndicator.prototype.get_y0 = function () {
        return new AccumulationDistributionIndicatorStrategy();
    };
    Object.defineProperty(AccumulationDistributionIndicator.prototype, "y0", {
        get: function () {
            return this.get_y0();
        },
        enumerable: false,
        configurable: true
    });
    AccumulationDistributionIndicator.prototype.get_zd = function () {
        return AccumulationDistributionIndicator.$;
    };
    Object.defineProperty(AccumulationDistributionIndicator.prototype, "zd", {
        get: function () {
            return this.get_zd();
        },
        enumerable: false,
        configurable: true
    });
    AccumulationDistributionIndicator.$t = markType(AccumulationDistributionIndicator, 'AccumulationDistributionIndicator', StrategyBasedIndicator.$);
    return AccumulationDistributionIndicator;
}(StrategyBasedIndicator));
export { AccumulationDistributionIndicator };
